@@ -86,6 +86,19 @@ final class AttributeList extends AbstractList<Attribute>
 
 	/** The parent Element */
 	private final Element parent;
+	
+	private static final Comparator<Attribute> ATTRIBUTE_NATURAL = new Comparator<Attribute>() {
+
+        @Override
+        public int compare(Attribute a1, Attribute a2) {
+            int pcomp = a1.getNamespacePrefix().compareTo(a2.getNamespacePrefix());
+            if (pcomp != 0) {
+                return pcomp;
+            }
+            return a1.getName().compareTo(a2.getName());
+        }
+	    
+	};
 
 	/**
 	 * Create a new instance of the AttributeList representing <i>parent</i>
@@ -309,7 +322,7 @@ final class AttributeList extends AbstractList<Attribute>
 		final int oldModCount = modCount;
 
 		// clear the current system
-		// we need to detatch before we add so that we don't run in to a problem
+		// we need to detach before we add so that we don't run in to a problem
 		// where an attribute in the to-add list is one that we are 'clearing'
 		// first.
 		while (size > 0) {
@@ -414,8 +427,8 @@ final class AttributeList extends AbstractList<Attribute>
 			final String uri = namespace.getURI();
 			for (int i = 0; i < size; i++) {
 				final Attribute att = attributeData[i];
-				if (uri.equals(att.getNamespaceURI()) &&
-						name.equals(att.getName())) {
+				if (att.getNamespaceURI().equals(uri) &&
+						att.getName().equals(name)) {
 					return i;
 				}
 			}
@@ -606,7 +619,10 @@ final class AttributeList extends AbstractList<Attribute>
 	 * 
 	 * @param comp The Comparator to use for sorting.
 	 */
-	void sort(Comparator<? super Attribute> comp) {
+	public void sort(Comparator<? super Attribute> comp) {
+	    if (comp == null) {
+	        comp = ATTRIBUTE_NATURAL;
+	    }
 		final int sz = size;
 		int[] indexes = new int[sz];
 		for (int i = 0 ; i < sz; i++) {
