@@ -107,7 +107,7 @@ public class Document extends CloneBase implements Parent {
 	 *
 	 * @param rootElement <code>Element</code> for document root.
 	 * @param docType <code>DocType</code> declaration.
-	 * @param baseURI the URI from which this doucment was loaded.
+	 * @param baseURI the URI from which this document was loaded.
 	 * @throws IllegalAddException if the given docType object
 	 *         is already attached to a document or the given
 	 *         rootElement already has a parent
@@ -426,6 +426,8 @@ public class Document extends CloneBase implements Parent {
 	 * </p>
 	 *
 	 * @param filter <code>Filter</code> to apply
+	 *        Note that the {@link Filters} class has a number of predefined, useful
+	 *        filters.
 	 * @return <code>List</code> - filtered Document content
 	 * @throws IllegalStateException if the root element hasn't been set
 	 */
@@ -452,6 +454,8 @@ public class Document extends CloneBase implements Parent {
 	 * Remove all child content from this parent matching the supplied filter.
 	 *
 	 * @param filter filter to select which content to remove
+	 *        Note that the {@link Filters} class has a number of predefined, useful
+	 *        filters.
 	 * @return list of the old children detached from this parent
 	 */
 	@Override
@@ -551,7 +555,7 @@ public class Document extends CloneBase implements Parent {
 	}
 
 	/**
-	 * Replace the child at the given index whith the supplied
+	 * Replace the child at the given index with the supplied
 	 * collection.
 	 * <p>
 	 * In event of an exception the original content will be unchanged and
@@ -684,7 +688,7 @@ public class Document extends CloneBase implements Parent {
 		final Document doc = (Document) super.clone();
 
 		// The clone has a reference to this object's content list, so
-		// owerwrite with a empty list
+		// overwrite with a empty list
 		doc.content = new ContentList(doc);
 
 		// Add the cloned content to clone
@@ -729,6 +733,8 @@ public class Document extends CloneBase implements Parent {
 	 * Comments, only Elements with a given name and/or prefix, and so on.
 	 *
 	 * @param filter filter to select which descendants to see
+	 *        Note that the {@link Filters} class has a number of predefined, useful
+	 *        filters.
 	 * @return an iterator to walk descendants within a filter
 	 */
 	@Override
@@ -749,7 +755,7 @@ public class Document extends CloneBase implements Parent {
 
 	/**
 	 * Always returns this Document Instance
-	 * @return 'this' because this Document is it's own Document
+	 * @return 'this' because this Document is its own Document
 	 */
 	@Override
 	public Document getDocument() {
@@ -826,6 +832,10 @@ public class Document extends CloneBase implements Parent {
 		}
 
 		if (child instanceof Text) {
+			if(Verifier.isAllXMLWhitespace(((Text) child).getText())) {
+				// only whitespace, not a problem.
+				return;
+			}
 			throw new IllegalAddException("A Text is not allowed at the document root");
 		}
 
