@@ -101,6 +101,7 @@ import org.jdom2.Content;
 import org.jdom2.DefaultJDOMFactory;
 import org.jdom2.Document;
 import org.jdom2.EntityRef;
+import org.jdom2.JDOMConstants;
 import org.jdom2.JDOMException;
 import org.jdom2.JDOMFactory;
 import org.jdom2.UncheckedJDOMFactory;
@@ -600,6 +601,27 @@ public final class TestSAXBuilder {
 		}
 	}
 
+	@Test
+	public void testSetExternalFeature() {
+		String feature = "http://xml.org/sax/features/external-general-entities";
+		MySAXBuilder sb = new MySAXBuilder();
+		try {
+			sb.setFeature(feature, true);
+			XMLReader reader = sb.createParser();
+			assertNotNull(reader);
+			assertTrue(reader.getFeature(feature));
+			assertNull(reader.getProperty(JDOMConstants.SAX_PROPERTY_DECLARATION_HANDLER));
+			sb.setFeature(feature, false);
+			reader = sb.createParser();
+			assertNotNull(reader);
+			assertFalse(reader.getFeature(feature));
+			assertNotNull(reader.getProperty(JDOMConstants.SAX_PROPERTY_DECLARATION_HANDLER));
+		} catch (Exception e) {
+			e.printStackTrace();
+			fail("Could not create parser: " + e.getMessage());
+		}
+	}
+
 	@Test
 	public void testSetProperty() {
 		LexicalHandler lh = new LexicalHandler() {
@@ -747,7 +769,7 @@ public final class TestSAXBuilder {
         builder.setExpandEntities(false);
         Document doc = builder.build(file);
 
-        assertTrue("didnt' get internal subset comments correctly", doc.getDocType().getInternalSubset().indexOf("foo") > 0);
+        assertTrue("did not get internal subset comments correctly", doc.getDocType().getInternalSubset().indexOf("foo") > 0);
 		//assertTrue("didn't get EntityRef for unexpanded attribute entities",
 		//	doc.getRootElement().getAttribute("test").getValue().indexOf("&simple") == 0);
 		
@@ -1094,6 +1116,18 @@ public final class TestSAXBuilder {
 			}
 		}
 	}
+
+	@Test
+    public void testXMLNamesVariants() throws JDOMException, IOException {
+        String toparse = "<xMl:xml xmlns:xMl='MyURI' xml='xml'/>";
+        
+        SAXBuilder sb = new SAXBuilder();
+        Document doc = sb.build(new CharArrayReader(toparse.toCharArray()));
+        
+        assertEquals("Should match:   xml", "xml" , doc.getRootElement().getAttributeValue("xml"));
+        
+        
+    }
 	
 	@Test
 	public void testBuildStringNegativeActualXML() {
@@ -1120,6 +1154,19 @@ public final class TestSAXBuilder {
 		}
 	}
 	
+	@Test
+	public void testSplitCDATAinCDATA() throws JDOMException, IOException {
+	    // Note the ]]><![CDATA[ in the middle
+	    String toparse = "<message><![CDATA[  expected:<[[D/0]]]]><![CDATA[> but was:<[null]>  ]]></message>";
+	    
+	    SAXBuilder sb = new SAXBuilder();
+	    Document doc = sb.build(new CharArrayReader(toparse.toCharArray()));
+	    
+	    assertEquals("Should match:   expected:<[[D/0]]> but was:<[null]>", "  expected:<[[D/0]]> but was:<[null]>  " , doc.getRootElement().getValue());
+	    
+	    
+	}
+	
 	@Test
 	public void testParserFactory() throws JDOMException, IOException {
 		if (System.getProperty("org.jdom2.performance") == null) {
